@@ -189,8 +189,14 @@ class Item(metaclass=ItemMetaclass):
         # │ CLASS ATTRIBUTES
         # └─────────────────────────────────────────────────────────────────────────────
 
+        # Initializeabstract
+        ABSTRACT: bool = False
+
+        # Initialize concrete attributes
+        CONCRETE_ATTRIBUTES: tuple[str, ...] = ()
+
         # Initialize items
-        ITEMS: Collection | Items | None = None
+        ITEMS: Collection[Any] | Items[Any] | None = None
 
         # Initialize keys
         KEYS: tuple[str | tuple[str, ...], ...] = ()
